
# Sensor Calibration Script for Compact Spoilage Detection Device

import time
import serial

# Set this to your serial port
SERIAL_PORT = '/dev/ttyUSB0'  # e.g., COM3 on Windows or /dev/ttyUSB0 on Linux
BAUD_RATE = 115200

# Open serial connection
ser = serial.Serial(SERIAL_PORT, BAUD_RATE, timeout=1)
time.sleep(2)  # wait for microcontroller to reboot

print("Starting baseline calibration...")
baseline_values = []

try:
    for _ in range(30):
        line = ser.readline().decode('utf-8').strip()
        if "Freshness:" in line:
            val = int(line.split(":")[1].strip())
            baseline_values.append(val)
            print(f"Reading: {val}")
        time.sleep(1)

    if baseline_values:
        baseline = sum(baseline_values) / len(baseline_values)
        print(f"Baseline Freshness Score: {baseline:.2f}")
    else:
        print("No valid data received. Check sensor and port.")

except KeyboardInterrupt:
    print("Calibration interrupted.")

finally:
    ser.close()
